package koeln.uni.idh.java1.zoo.ui;

public class AsciiImage {

	/**
	 * The width of an image
	 */
	int width;

	/**
	 * The image itself, as ASCII-art
	 */
	String image;

	/**
	 * Creates a new empty image with the given width, which is expressed as the
	 * number of columns in each line.
	 * 
	 * @param width An integer value that represents the width of the image
	 */
	public AsciiImage(int width) {
		this.width = width;

		// Initially, the image is empty
		this.image = "";
	}

	/**
	 * Adds an empty line to the image
	 */
	public void emptyLine() {
		for (int i = 0; i < width; i++) {
			this.image = this.image + ".";
		}
		this.image = this.image + "\n";
	}

	/**
	 * Adds a line with a single dot to the image. The position of the dot is given
	 * as the argument.
	 * 
	 * @param dotPosition column number of the black pixel
	 */
	public void lineWithDot(int dotPosition) {
		this.lineWithDots(new int[] { dotPosition });
	}

	/**
	 * Adds a line with multiple black pixels to the image. The positions of the
	 * pixels are given in the form of an array argument.
	 * 
	 * @param dotPositions The positions of the pixels. The order of the array does
	 *                     not matter.
	 */
	public void lineWithDots(int[] dotPositions) {
		for (int i = 0; i < width; i++) {
			if (contains(dotPositions, i)) {
				this.image = this.image + "#";
			} else {
				this.image = this.image + ".";
			}
		}
		this.image = this.image + "\n";
	}

	public String toString() {
		return this.image;
	}

	/**
	 * Utility function to determine, whether an int-Array contains a specific
	 * int-value. The method returns true as soon as the value has been found.
	 * 
	 * @param arr  The array we want to search
	 * @param item The item we are looking for
	 * @return true if arr contains item, false otherwise
	 */
	private boolean contains(int[] arr, int item) {
		// for loop over the entire array
		for (int i = 0; i < arr.length; i++) {
			// each element is compared with the item we are looking for
			if (arr[i] == item)
				// if they are equal, we immediately return true
				return true;
		}
		// if we reach this line, we have not yet returned true, which means the item is
		// not contained in the array. Thus we return false.
		return false;
	}

	public void fullLine() {
		for (int i = 0; i < width; i++) {
			this.image = this.image + "#";
		}
		this.image = this.image + "\n";		
	}

}
